from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Devices.Bluetooth
import win32more.Windows.Win32.Foundation
AUTHENTICATION_REQUIREMENTS = Int32
MITMProtectionNotRequired: win32more.Windows.Win32.Devices.Bluetooth.AUTHENTICATION_REQUIREMENTS = 0
MITMProtectionRequired: win32more.Windows.Win32.Devices.Bluetooth.AUTHENTICATION_REQUIREMENTS = 1
MITMProtectionNotRequiredBonding: win32more.Windows.Win32.Devices.Bluetooth.AUTHENTICATION_REQUIREMENTS = 2
MITMProtectionRequiredBonding: win32more.Windows.Win32.Devices.Bluetooth.AUTHENTICATION_REQUIREMENTS = 3
MITMProtectionNotRequiredGeneralBonding: win32more.Windows.Win32.Devices.Bluetooth.AUTHENTICATION_REQUIREMENTS = 4
MITMProtectionRequiredGeneralBonding: win32more.Windows.Win32.Devices.Bluetooth.AUTHENTICATION_REQUIREMENTS = 5
MITMProtectionNotDefined: win32more.Windows.Win32.Devices.Bluetooth.AUTHENTICATION_REQUIREMENTS = 255
BTH_MAJORVERSION: UInt32 = 2
BTH_MINORVERSION: UInt32 = 1
GUID_BTHPORT_DEVICE_INTERFACE: Guid = Guid('{0850302a-b344-4fda-9be9-90576b8d46f0}')
GUID_BTH_RFCOMM_SERVICE_DEVICE_INTERFACE: Guid = Guid('{b142fc3e-fa4e-460b-8abc-072b628b3c70}')
GUID_BLUETOOTH_RADIO_IN_RANGE: Guid = Guid('{ea3b5b82-26ee-450e-b0d8-d26fe30a3869}')
GUID_BLUETOOTH_RADIO_OUT_OF_RANGE: Guid = Guid('{e28867c9-c2aa-4ced-b969-4570866037c4}')
GUID_BLUETOOTH_L2CAP_EVENT: Guid = Guid('{7eae4030-b709-4aa8-ac55-e953829c9daa}')
GUID_BLUETOOTH_HCI_EVENT: Guid = Guid('{fc240062-1541-49be-b463-84c4dcd7bf7f}')
GUID_BLUETOOTH_AUTHENTICATION_REQUEST: Guid = Guid('{5dc9136d-996c-46db-84f5-32c0a3f47352}')
GUID_BLUETOOTH_KEYPRESS_EVENT: Guid = Guid('{d668dfcd-0f4e-4efc-bfe0-392eeec5109c}')
GUID_BLUETOOTH_HCI_VENDOR_EVENT: Guid = Guid('{547247e6-45bb-4c33-af8c-c00efe15a71d}')
Bluetooth_Base_UUID: Guid = Guid('{00000000-0000-1000-8000-00805f9b34fb}')
SDP_PROTOCOL_UUID16: UInt32 = 1
UDP_PROTOCOL_UUID16: UInt32 = 2
RFCOMM_PROTOCOL_UUID16: UInt32 = 3
TCP_PROTOCOL_UUID16: UInt32 = 4
TCSBIN_PROTOCOL_UUID16: UInt32 = 5
TCSAT_PROTOCOL_UUID16: UInt32 = 6
ATT_PROTOCOL_UUID16: UInt32 = 7
OBEX_PROTOCOL_UUID16: UInt32 = 8
IP_PROTOCOL_UUID16: UInt32 = 9
FTP_PROTOCOL_UUID16: UInt32 = 10
HTTP_PROTOCOL_UUID16: UInt32 = 12
WSP_PROTOCOL_UUID16: UInt32 = 14
BNEP_PROTOCOL_UUID16: UInt32 = 15
UPNP_PROTOCOL_UUID16: UInt32 = 16
HID_PROTOCOL_UUID16: UInt32 = 17
HCCC_PROTOCOL_UUID16: UInt32 = 18
HCDC_PROTOCOL_UUID16: UInt32 = 20
HCN_PROTOCOL_UUID16: UInt32 = 22
AVCTP_PROTOCOL_UUID16: UInt32 = 23
AVDTP_PROTOCOL_UUID16: UInt32 = 25
CMPT_PROTOCOL_UUID16: UInt32 = 27
UDI_C_PLANE_PROTOCOL_UUID16: UInt32 = 29
L2CAP_PROTOCOL_UUID16: UInt32 = 256
ServiceDiscoveryServerServiceClassID_UUID16: UInt32 = 4096
BrowseGroupDescriptorServiceClassID_UUID16: UInt32 = 4097
PublicBrowseGroupServiceClassID_UUID16: UInt32 = 4098
SerialPortServiceClassID_UUID16: UInt32 = 4353
LANAccessUsingPPPServiceClassID_UUID16: UInt32 = 4354
DialupNetworkingServiceClassID_UUID16: UInt32 = 4355
IrMCSyncServiceClassID_UUID16: UInt32 = 4356
OBEXObjectPushServiceClassID_UUID16: UInt32 = 4357
OBEXFileTransferServiceClassID_UUID16: UInt32 = 4358
IrMcSyncCommandServiceClassID_UUID16: UInt32 = 4359
HeadsetServiceClassID_UUID16: UInt32 = 4360
CordlessTelephonyServiceClassID_UUID16: UInt32 = 4361
AudioSourceServiceClassID_UUID16: UInt32 = 4362
AudioSinkServiceClassID_UUID16: UInt32 = 4363
AVRemoteControlTargetServiceClassID_UUID16: UInt32 = 4364
AVRemoteControlServiceClassID_UUID16: UInt32 = 4366
AVRemoteControlControllerServiceClass_UUID16: UInt32 = 4367
IntercomServiceClassID_UUID16: UInt32 = 4368
FaxServiceClassID_UUID16: UInt32 = 4369
HeadsetAudioGatewayServiceClassID_UUID16: UInt32 = 4370
WAPServiceClassID_UUID16: UInt32 = 4371
WAPClientServiceClassID_UUID16: UInt32 = 4372
PANUServiceClassID_UUID16: UInt32 = 4373
NAPServiceClassID_UUID16: UInt32 = 4374
GNServiceClassID_UUID16: UInt32 = 4375
DirectPrintingServiceClassID_UUID16: UInt32 = 4376
ReferencePrintingServiceClassID_UUID16: UInt32 = 4377
ImagingResponderServiceClassID_UUID16: UInt32 = 4379
ImagingAutomaticArchiveServiceClassID_UUID16: UInt32 = 4380
ImagingReferenceObjectsServiceClassID_UUID16: UInt32 = 4381
HandsfreeServiceClassID_UUID16: UInt32 = 4382
HandsfreeAudioGatewayServiceClassID_UUID16: UInt32 = 4383
DirectPrintingReferenceObjectsServiceClassID_UUID16: UInt32 = 4384
ReflectsUIServiceClassID_UUID16: UInt32 = 4385
PrintingStatusServiceClassID_UUID16: UInt32 = 4387
HumanInterfaceDeviceServiceClassID_UUID16: UInt32 = 4388
HCRPrintServiceClassID_UUID16: UInt32 = 4390
HCRScanServiceClassID_UUID16: UInt32 = 4391
CommonISDNAccessServiceClassID_UUID16: UInt32 = 4392
VideoConferencingGWServiceClassID_UUID16: UInt32 = 4393
UDIMTServiceClassID_UUID16: UInt32 = 4394
UDITAServiceClassID_UUID16: UInt32 = 4395
AudioVideoServiceClassID_UUID16: UInt32 = 4396
SimAccessServiceClassID_UUID16: UInt32 = 4397
PhonebookAccessPceServiceClassID_UUID16: UInt32 = 4398
PhonebookAccessPseServiceClassID_UUID16: UInt32 = 4399
HeadsetHSServiceClassID_UUID16: UInt32 = 4401
MessageAccessServerServiceClassID_UUID16: UInt32 = 4402
MessageNotificationServerServiceClassID_UUID16: UInt32 = 4403
GNSSServerServiceClassID_UUID16: UInt32 = 4406
ThreeDimensionalDisplayServiceClassID_UUID16: UInt32 = 4407
ThreeDimensionalGlassesServiceClassID_UUID16: UInt32 = 4408
MPSServiceClassID_UUID16: UInt32 = 4411
CTNAccessServiceClassID_UUID16: UInt32 = 4412
CTNNotificationServiceClassID_UUID16: UInt32 = 4413
PnPInformationServiceClassID_UUID16: UInt32 = 4608
GenericNetworkingServiceClassID_UUID16: UInt32 = 4609
GenericFileTransferServiceClassID_UUID16: UInt32 = 4610
GenericAudioServiceClassID_UUID16: UInt32 = 4611
GenericTelephonyServiceClassID_UUID16: UInt32 = 4612
UPnpServiceClassID_UUID16: UInt32 = 4613
UPnpIpServiceClassID_UUID16: UInt32 = 4614
ESdpUpnpIpPanServiceClassID_UUID16: UInt32 = 4864
ESdpUpnpIpLapServiceClassID_UUID16: UInt32 = 4865
ESdpUpnpL2capServiceClassID_UUID16: UInt32 = 4866
VideoSourceServiceClassID_UUID16: UInt32 = 4867
VideoSinkServiceClassID_UUID16: UInt32 = 4868
HealthDeviceProfileSourceServiceClassID_UUID16: UInt32 = 5121
HealthDeviceProfileSinkServiceClassID_UUID16: UInt32 = 5122
AdvancedAudioDistributionProfileID_UUID16: UInt32 = 4365
ImagingServiceProfileID_UUID16: UInt32 = 4378
BasicPrintingProfileID_UUID16: UInt32 = 4386
HardcopyCableReplacementProfileID_UUID16: UInt32 = 4389
PhonebookAccessProfileID_UUID16: UInt32 = 4400
MessageAccessProfileID_UUID16: UInt32 = 4404
GNSSProfileID_UUID16: UInt32 = 4405
ThreeDimensionalSynchronizationProfileID_UUID16: UInt32 = 4409
MPSProfileID_UUID16: UInt32 = 4410
CTNProfileID_UUID16: UInt32 = 4414
VideoDistributionProfileID_UUID16: UInt32 = 4869
HealthDeviceProfileID_UUID16: UInt32 = 5120
VideoConferencingServiceClassID_UUID16: UInt32 = 4367
CommonISDNAccessServiceClass_UUID16: UInt32 = 4392
VideoConferencingGWServiceClass_UUID16: UInt32 = 4393
UDIMTServiceClass_UUID16: UInt32 = 4394
UDITAServiceClass_UUID16: UInt32 = 4395
AudioVideoServiceClass_UUID16: UInt32 = 4396
CordlessServiceClassID_UUID16: UInt32 = 4361
AudioSinkSourceServiceClassID_UUID16: UInt32 = 4363
AdvancedAudioDistributionServiceClassID_UUID16: UInt32 = 4365
ImagingServiceClassID_UUID16: UInt32 = 4378
BasicPrintingServiceClassID_UUID16: UInt32 = 4386
HardcopyCableReplacementServiceClassID_UUID16: UInt32 = 4389
BTH_MAX_NAME_SIZE: UInt32 = 248
BTH_MAX_PIN_SIZE: UInt32 = 16
BTH_LINK_KEY_LENGTH: UInt32 = 16
BTH_MFG_ERICSSON: UInt32 = 0
BTH_MFG_NOKIA: UInt32 = 1
BTH_MFG_INTEL: UInt32 = 2
BTH_MFG_IBM: UInt32 = 3
BTH_MFG_TOSHIBA: UInt32 = 4
BTH_MFG_3COM: UInt32 = 5
BTH_MFG_MICROSOFT: UInt32 = 6
BTH_MFG_LUCENT: UInt32 = 7
BTH_MFG_MOTOROLA: UInt32 = 8
BTH_MFG_INFINEON: UInt32 = 9
BTH_MFG_CSR: UInt32 = 10
BTH_MFG_SILICONWAVE: UInt32 = 11
BTH_MFG_DIGIANSWER: UInt32 = 12
BTH_MFG_TI: UInt32 = 13
BTH_MFG_PARTHUS: UInt32 = 14
BTH_MFG_BROADCOM: UInt32 = 15
BTH_MFG_MITEL: UInt32 = 16
BTH_MFG_WIDCOMM: UInt32 = 17
BTH_MFG_ZEEVO: UInt32 = 18
BTH_MFG_ATMEL: UInt32 = 19
BTH_MFG_MITSIBUSHI: UInt32 = 20
BTH_MFG_RTX_TELECOM: UInt32 = 21
BTH_MFG_KC_TECHNOLOGY: UInt32 = 22
BTH_MFG_NEWLOGIC: UInt32 = 23
BTH_MFG_TRANSILICA: UInt32 = 24
BTH_MFG_ROHDE_SCHWARZ: UInt32 = 25
BTH_MFG_TTPCOM: UInt32 = 26
BTH_MFG_SIGNIA: UInt32 = 27
BTH_MFG_CONEXANT: UInt32 = 28
BTH_MFG_QUALCOMM: UInt32 = 29
BTH_MFG_INVENTEL: UInt32 = 30
BTH_MFG_AVM_BERLIN: UInt32 = 31
BTH_MFG_BANDSPEED: UInt32 = 32
BTH_MFG_MANSELLA: UInt32 = 33
BTH_MFG_NEC: UInt32 = 34
BTH_MFG_WAVEPLUS_TECHNOLOGY_CO: UInt32 = 35
BTH_MFG_ALCATEL: UInt32 = 36
BTH_MFG_PHILIPS_SEMICONDUCTOR: UInt32 = 37
BTH_MFG_C_TECHNOLOGIES: UInt32 = 38
BTH_MFG_OPEN_INTERFACE: UInt32 = 39
BTH_MFG_RF_MICRO_DEVICES: UInt32 = 40
BTH_MFG_HITACHI: UInt32 = 41
BTH_MFG_SYMBOL_TECHNOLOGIES: UInt32 = 42
BTH_MFG_TENOVIS: UInt32 = 43
BTH_MFG_MACRONIX_INTERNATIONAL: UInt32 = 44
BTH_MFG_MARVELL: UInt32 = 72
BTH_MFG_APPLE: UInt32 = 76
BTH_MFG_NORDIC_SEMICONDUCTORS_ASA: UInt32 = 89
BTH_MFG_ARUBA_NETWORKS: UInt32 = 283
BTH_MFG_INTERNAL_USE: UInt32 = 65535
SAP_BIT_OFFSET: UInt32 = 0
COD_FORMAT_BIT_OFFSET: UInt32 = 0
COD_MINOR_BIT_OFFSET: UInt32 = 2
COD_FORMAT_MASK: UInt32 = 3
COD_MINOR_MASK: UInt32 = 252
COD_MAJOR_MASK: UInt32 = 7936
COD_SERVICE_MASK: UInt32 = 16769024
COD_VERSION: UInt32 = 0
COD_SERVICE_LIMITED: UInt32 = 1
COD_SERVICE_LE_AUDIO: UInt32 = 2
COD_SERVICE_POSITIONING: UInt32 = 8
COD_SERVICE_NETWORKING: UInt32 = 16
COD_SERVICE_RENDERING: UInt32 = 32
COD_SERVICE_CAPTURING: UInt32 = 64
COD_SERVICE_OBJECT_XFER: UInt32 = 128
COD_SERVICE_AUDIO: UInt32 = 256
COD_SERVICE_TELEPHONY: UInt32 = 512
COD_SERVICE_INFORMATION: UInt32 = 1024
COD_SERVICE_MAX_COUNT: UInt32 = 10
COD_MAJOR_MISCELLANEOUS: UInt32 = 0
COD_MAJOR_COMPUTER: UInt32 = 1
COD_MAJOR_PHONE: UInt32 = 2
COD_MAJOR_LAN_ACCESS: UInt32 = 3
COD_MAJOR_AUDIO: UInt32 = 4
COD_MAJOR_PERIPHERAL: UInt32 = 5
COD_MAJOR_IMAGING: UInt32 = 6
COD_MAJOR_WEARABLE: UInt32 = 7
COD_MAJOR_TOY: UInt32 = 8
COD_MAJOR_HEALTH: UInt32 = 9
COD_MAJOR_UNCLASSIFIED: UInt32 = 31
COD_COMPUTER_MINOR_UNCLASSIFIED: UInt32 = 0
COD_COMPUTER_MINOR_DESKTOP: UInt32 = 1
COD_COMPUTER_MINOR_SERVER: UInt32 = 2
COD_COMPUTER_MINOR_LAPTOP: UInt32 = 3
COD_COMPUTER_MINOR_HANDHELD: UInt32 = 4
COD_COMPUTER_MINOR_PALM: UInt32 = 5
COD_COMPUTER_MINOR_WEARABLE: UInt32 = 6
COD_PHONE_MINOR_UNCLASSIFIED: UInt32 = 0
COD_PHONE_MINOR_CELLULAR: UInt32 = 1
COD_PHONE_MINOR_CORDLESS: UInt32 = 2
COD_PHONE_MINOR_SMART: UInt32 = 3
COD_PHONE_MINOR_WIRED_MODEM: UInt32 = 4
COD_AUDIO_MINOR_UNCLASSIFIED: UInt32 = 0
COD_AUDIO_MINOR_HEADSET: UInt32 = 1
COD_AUDIO_MINOR_HANDS_FREE: UInt32 = 2
COD_AUDIO_MINOR_HEADSET_HANDS_FREE: UInt32 = 3
COD_AUDIO_MINOR_MICROPHONE: UInt32 = 4
COD_AUDIO_MINOR_LOUDSPEAKER: UInt32 = 5
COD_AUDIO_MINOR_HEADPHONES: UInt32 = 6
COD_AUDIO_MINOR_PORTABLE_AUDIO: UInt32 = 7
COD_AUDIO_MINOR_CAR_AUDIO: UInt32 = 8
COD_AUDIO_MINOR_SET_TOP_BOX: UInt32 = 9
COD_AUDIO_MINOR_HIFI_AUDIO: UInt32 = 10
COD_AUDIO_MINOR_VCR: UInt32 = 11
COD_AUDIO_MINOR_VIDEO_CAMERA: UInt32 = 12
COD_AUDIO_MINOR_CAMCORDER: UInt32 = 13
COD_AUDIO_MINOR_VIDEO_MONITOR: UInt32 = 14
COD_AUDIO_MINOR_VIDEO_DISPLAY_LOUDSPEAKER: UInt32 = 15
COD_AUDIO_MINOR_VIDEO_DISPLAY_CONFERENCING: UInt32 = 16
COD_AUDIO_MINOR_GAMING_TOY: UInt32 = 18
COD_PERIPHERAL_MINOR_KEYBOARD_MASK: UInt32 = 16
COD_PERIPHERAL_MINOR_POINTER_MASK: UInt32 = 32
COD_PERIPHERAL_MINOR_NO_CATEGORY: UInt32 = 0
COD_PERIPHERAL_MINOR_JOYSTICK: UInt32 = 1
COD_PERIPHERAL_MINOR_GAMEPAD: UInt32 = 2
COD_PERIPHERAL_MINOR_REMOTE_CONTROL: UInt32 = 3
COD_PERIPHERAL_MINOR_SENSING: UInt32 = 4
COD_IMAGING_MINOR_DISPLAY_MASK: UInt32 = 4
COD_IMAGING_MINOR_CAMERA_MASK: UInt32 = 8
COD_IMAGING_MINOR_SCANNER_MASK: UInt32 = 16
COD_IMAGING_MINOR_PRINTER_MASK: UInt32 = 32
COD_WEARABLE_MINOR_WRIST_WATCH: UInt32 = 1
COD_WEARABLE_MINOR_PAGER: UInt32 = 2
COD_WEARABLE_MINOR_JACKET: UInt32 = 3
COD_WEARABLE_MINOR_HELMET: UInt32 = 4
COD_WEARABLE_MINOR_GLASSES: UInt32 = 5
COD_TOY_MINOR_ROBOT: UInt32 = 1
COD_TOY_MINOR_VEHICLE: UInt32 = 2
COD_TOY_MINOR_DOLL_ACTION_FIGURE: UInt32 = 3
COD_TOY_MINOR_CONTROLLER: UInt32 = 4
COD_TOY_MINOR_GAME: UInt32 = 5
COD_HEALTH_MINOR_BLOOD_PRESSURE_MONITOR: UInt32 = 1
COD_HEALTH_MINOR_THERMOMETER: UInt32 = 2
COD_HEALTH_MINOR_WEIGHING_SCALE: UInt32 = 3
COD_HEALTH_MINOR_GLUCOSE_METER: UInt32 = 4
COD_HEALTH_MINOR_PULSE_OXIMETER: UInt32 = 5
COD_HEALTH_MINOR_HEART_PULSE_MONITOR: UInt32 = 6
COD_HEALTH_MINOR_HEALTH_DATA_DISPLAY: UInt32 = 7
COD_HEALTH_MINOR_STEP_COUNTER: UInt32 = 8
COD_LAN_ACCESS_BIT_OFFSET: UInt32 = 5
COD_LAN_MINOR_MASK: UInt32 = 28
COD_LAN_ACCESS_MASK: UInt32 = 224
COD_LAN_MINOR_UNCLASSIFIED: UInt32 = 0
COD_LAN_ACCESS_0_USED: UInt32 = 0
COD_LAN_ACCESS_17_USED: UInt32 = 1
COD_LAN_ACCESS_33_USED: UInt32 = 2
COD_LAN_ACCESS_50_USED: UInt32 = 3
COD_LAN_ACCESS_67_USED: UInt32 = 4
COD_LAN_ACCESS_83_USED: UInt32 = 5
COD_LAN_ACCESS_99_USED: UInt32 = 6
COD_LAN_ACCESS_FULL: UInt32 = 7
BTH_EIR_FLAGS_ID: UInt32 = 1
BTH_EIR_16_UUIDS_PARTIAL_ID: UInt32 = 2
BTH_EIR_16_UUIDS_COMPLETE_ID: UInt32 = 3
BTH_EIR_32_UUIDS_PARTIAL_ID: UInt32 = 4
BTH_EIR_32_UUIDS_COMPLETE_ID: UInt32 = 5
BTH_EIR_128_UUIDS_PARTIAL_ID: UInt32 = 6
BTH_EIR_128_UUIDS_COMPLETE_ID: UInt32 = 7
BTH_EIR_LOCAL_NAME_PARTIAL_ID: UInt32 = 8
BTH_EIR_LOCAL_NAME_COMPLETE_ID: UInt32 = 9
BTH_EIR_TX_POWER_LEVEL_ID: UInt32 = 10
BTH_EIR_OOB_OPT_DATA_LEN_ID: UInt32 = 11
BTH_EIR_OOB_BD_ADDR_ID: UInt32 = 12
BTH_EIR_OOB_COD_ID: UInt32 = 13
BTH_EIR_OOB_SP_HASH_ID: UInt32 = 14
BTH_EIR_OOB_SP_RANDOMIZER_ID: UInt32 = 15
BTH_EIR_MANUFACTURER_ID: UInt32 = 255
BTH_EIR_SIZE: UInt32 = 240
LAP_GIAC_VALUE: UInt32 = 10390323
LAP_LIAC_VALUE: UInt32 = 10390272
BTH_ADDR_IAC_FIRST: UInt32 = 10390272
BTH_ADDR_IAC_LAST: UInt32 = 10390335
BTH_ADDR_LIAC: UInt32 = 10390272
BTH_ADDR_GIAC: UInt32 = 10390323
BTH_ERROR_SUCCESS: UInt32 = 0
BTH_ERROR_UNKNOWN_HCI_COMMAND: UInt32 = 1
BTH_ERROR_NO_CONNECTION: UInt32 = 2
BTH_ERROR_HARDWARE_FAILURE: UInt32 = 3
BTH_ERROR_PAGE_TIMEOUT: UInt32 = 4
BTH_ERROR_AUTHENTICATION_FAILURE: UInt32 = 5
BTH_ERROR_KEY_MISSING: UInt32 = 6
BTH_ERROR_MEMORY_FULL: UInt32 = 7
BTH_ERROR_CONNECTION_TIMEOUT: UInt32 = 8
BTH_ERROR_MAX_NUMBER_OF_CONNECTIONS: UInt32 = 9
BTH_ERROR_MAX_NUMBER_OF_SCO_CONNECTIONS: UInt32 = 10
BTH_ERROR_ACL_CONNECTION_ALREADY_EXISTS: UInt32 = 11
BTH_ERROR_COMMAND_DISALLOWED: UInt32 = 12
BTH_ERROR_HOST_REJECTED_LIMITED_RESOURCES: UInt32 = 13
BTH_ERROR_HOST_REJECTED_SECURITY_REASONS: UInt32 = 14
BTH_ERROR_HOST_REJECTED_PERSONAL_DEVICE: UInt32 = 15
BTH_ERROR_HOST_TIMEOUT: UInt32 = 16
BTH_ERROR_UNSUPPORTED_FEATURE_OR_PARAMETER: UInt32 = 17
BTH_ERROR_INVALID_HCI_PARAMETER: UInt32 = 18
BTH_ERROR_REMOTE_USER_ENDED_CONNECTION: UInt32 = 19
BTH_ERROR_REMOTE_LOW_RESOURCES: UInt32 = 20
BTH_ERROR_REMOTE_POWERING_OFF: UInt32 = 21
BTH_ERROR_LOCAL_HOST_TERMINATED_CONNECTION: UInt32 = 22
BTH_ERROR_REPEATED_ATTEMPTS: UInt32 = 23
BTH_ERROR_PAIRING_NOT_ALLOWED: UInt32 = 24
BTH_ERROR_UKNOWN_LMP_PDU: UInt32 = 25
BTH_ERROR_UNSUPPORTED_REMOTE_FEATURE: UInt32 = 26
BTH_ERROR_SCO_OFFSET_REJECTED: UInt32 = 27
BTH_ERROR_SCO_INTERVAL_REJECTED: UInt32 = 28
BTH_ERROR_SCO_AIRMODE_REJECTED: UInt32 = 29
BTH_ERROR_INVALID_LMP_PARAMETERS: UInt32 = 30
BTH_ERROR_UNSPECIFIED_ERROR: UInt32 = 31
BTH_ERROR_UNSUPPORTED_LMP_PARM_VALUE: UInt32 = 32
BTH_ERROR_ROLE_CHANGE_NOT_ALLOWED: UInt32 = 33
BTH_ERROR_LMP_RESPONSE_TIMEOUT: UInt32 = 34
BTH_ERROR_LMP_TRANSACTION_COLLISION: UInt32 = 35
BTH_ERROR_LMP_PDU_NOT_ALLOWED: UInt32 = 36
BTH_ERROR_ENCRYPTION_MODE_NOT_ACCEPTABLE: UInt32 = 37
BTH_ERROR_UNIT_KEY_NOT_USED: UInt32 = 38
BTH_ERROR_QOS_IS_NOT_SUPPORTED: UInt32 = 39
BTH_ERROR_INSTANT_PASSED: UInt32 = 40
BTH_ERROR_PAIRING_WITH_UNIT_KEY_NOT_SUPPORTED: UInt32 = 41
BTH_ERROR_DIFFERENT_TRANSACTION_COLLISION: UInt32 = 42
BTH_ERROR_QOS_UNACCEPTABLE_PARAMETER: UInt32 = 44
BTH_ERROR_QOS_REJECTED: UInt32 = 45
BTH_ERROR_CHANNEL_CLASSIFICATION_NOT_SUPPORTED: UInt32 = 46
BTH_ERROR_INSUFFICIENT_SECURITY: UInt32 = 47
BTH_ERROR_PARAMETER_OUT_OF_MANDATORY_RANGE: UInt32 = 48
BTH_ERROR_ROLE_SWITCH_PENDING: UInt32 = 50
BTH_ERROR_RESERVED_SLOT_VIOLATION: UInt32 = 52
BTH_ERROR_ROLE_SWITCH_FAILED: UInt32 = 53
BTH_ERROR_EXTENDED_INQUIRY_RESPONSE_TOO_LARGE: UInt32 = 54
BTH_ERROR_SECURE_SIMPLE_PAIRING_NOT_SUPPORTED_BY_HOST: UInt32 = 55
BTH_ERROR_HOST_BUSY_PAIRING: UInt32 = 56
BTH_ERROR_CONNECTION_REJECTED_DUE_TO_NO_SUITABLE_CHANNEL_FOUND: UInt32 = 57
BTH_ERROR_CONTROLLER_BUSY: UInt32 = 58
BTH_ERROR_UNACCEPTABLE_CONNECTION_INTERVAL: UInt32 = 59
BTH_ERROR_DIRECTED_ADVERTISING_TIMEOUT: UInt32 = 60
BTH_ERROR_CONNECTION_TERMINATED_DUE_TO_MIC_FAILURE: UInt32 = 61
BTH_ERROR_CONNECTION_FAILED_TO_BE_ESTABLISHED: UInt32 = 62
BTH_ERROR_MAC_CONNECTION_FAILED: UInt32 = 63
BTH_ERROR_COARSE_CLOCK_ADJUSTMENT_REJECTED: UInt32 = 64
BTH_ERROR_TYPE_0_SUBMAP_NOT_DEFINED: UInt32 = 65
BTH_ERROR_UNKNOWN_ADVERTISING_IDENTIFIER: UInt32 = 66
BTH_ERROR_LIMIT_REACHED: UInt32 = 67
BTH_ERROR_OPERATION_CANCELLED_BY_HOST: UInt32 = 68
BTH_ERROR_PACKET_TOO_LONG: UInt32 = 69
BTH_ERROR_UNSPECIFIED: UInt32 = 255
L2CAP_MIN_MTU: UInt32 = 48
L2CAP_MAX_MTU: UInt32 = 65535
L2CAP_DEFAULT_MTU: UInt32 = 672
MAX_L2CAP_PING_DATA_LENGTH: UInt32 = 44
MAX_L2CAP_INFO_DATA_LENGTH: UInt32 = 44
BDIF_ADDRESS: UInt32 = 1
BDIF_COD: UInt32 = 2
BDIF_NAME: UInt32 = 4
BDIF_PAIRED: UInt32 = 8
BDIF_PERSONAL: UInt32 = 16
BDIF_CONNECTED: UInt32 = 32
BDIF_SHORT_NAME: UInt32 = 64
BDIF_VISIBLE: UInt32 = 128
BDIF_SSP_SUPPORTED: UInt32 = 256
BDIF_SSP_PAIRED: UInt32 = 512
BDIF_SSP_MITM_PROTECTED: UInt32 = 1024
BDIF_RSSI: UInt32 = 4096
BDIF_EIR: UInt32 = 8192
BDIF_BR: UInt32 = 16384
BDIF_LE: UInt32 = 32768
BDIF_LE_PAIRED: UInt32 = 65536
BDIF_LE_PERSONAL: UInt32 = 131072
BDIF_LE_MITM_PROTECTED: UInt32 = 262144
BDIF_LE_PRIVACY_ENABLED: UInt32 = 524288
BDIF_LE_RANDOM_ADDRESS_TYPE: UInt32 = 1048576
BDIF_LE_DISCOVERABLE: UInt32 = 2097152
BDIF_LE_NAME: UInt32 = 4194304
BDIF_LE_VISIBLE: UInt32 = 8388608
BDIF_LE_CONNECTED: UInt32 = 16777216
BDIF_LE_CONNECTABLE: UInt32 = 33554432
BDIF_BR_SECURE_CONNECTION_PAIRED: UInt32 = 134217728
BDIF_LE_SECURE_CONNECTION_PAIRED: UInt32 = 268435456
BDIF_DEBUGKEY: UInt32 = 536870912
BDIF_LE_DEBUGKEY: UInt32 = 1073741824
BDIF_TX_POWER: UInt32 = 2147483648
HCI_CONNECTION_TYPE_ACL: UInt32 = 1
HCI_CONNECTION_TYPE_SCO: UInt32 = 2
HCI_CONNECTION_TYPE_LE: UInt32 = 3
HCI_CONNNECTION_TYPE_ACL: UInt32 = 1
HCI_CONNNECTION_TYPE_SCO: UInt32 = 2
BTH_MAX_SERVICE_NAME_SIZE: UInt32 = 256
MAX_UUIDS_IN_QUERY: UInt32 = 12
BTH_VID_DEFAULT_VALUE: UInt32 = 65535
SDP_ERROR_INVALID_SDP_VERSION: UInt32 = 1
SDP_ERROR_INVALID_RECORD_HANDLE: UInt32 = 2
SDP_ERROR_INVALID_REQUEST_SYNTAX: UInt32 = 3
SDP_ERROR_INVALID_PDU_SIZE: UInt32 = 4
SDP_ERROR_INVALID_CONTINUATION_STATE: UInt32 = 5
SDP_ERROR_INSUFFICIENT_RESOURCES: UInt32 = 6
SDP_ATTRIB_RECORD_HANDLE: UInt32 = 0
SDP_ATTRIB_CLASS_ID_LIST: UInt32 = 1
SDP_ATTRIB_RECORD_STATE: UInt32 = 2
SDP_ATTRIB_SERVICE_ID: UInt32 = 3
SDP_ATTRIB_PROTOCOL_DESCRIPTOR_LIST: UInt32 = 4
SDP_ATTRIB_BROWSE_GROUP_LIST: UInt32 = 5
SDP_ATTRIB_LANG_BASE_ATTRIB_ID_LIST: UInt32 = 6
SDP_ATTRIB_INFO_TIME_TO_LIVE: UInt32 = 7
SDP_ATTRIB_AVAILABILITY: UInt32 = 8
SDP_ATTRIB_PROFILE_DESCRIPTOR_LIST: UInt32 = 9
SDP_ATTRIB_DOCUMENTATION_URL: UInt32 = 10
SDP_ATTRIB_CLIENT_EXECUTABLE_URL: UInt32 = 11
SDP_ATTRIB_ICON_URL: UInt32 = 12
SDP_ATTRIB_ADDITIONAL_PROTOCOL_DESCRIPTOR_LIST: UInt32 = 13
SDP_ATTRIB_PROFILE_SPECIFIC: UInt32 = 512
LANG_BASE_LANGUAGE_INDEX: UInt32 = 0
LANG_BASE_ENCODING_INDEX: UInt32 = 1
LANG_BASE_OFFSET_INDEX: UInt32 = 2
LANG_DEFAULT_ID: UInt32 = 256
LANGUAGE_EN_US: UInt32 = 25966
ENCODING_UTF_8: UInt32 = 106
STRING_NAME_OFFSET: UInt32 = 0
STRING_DESCRIPTION_OFFSET: UInt32 = 1
STRING_PROVIDER_NAME_OFFSET: UInt32 = 2
SDP_ATTRIB_SDP_VERSION_NUMBER_LIST: UInt32 = 512
SDP_ATTRIB_SDP_DATABASE_STATE: UInt32 = 513
SDP_ATTRIB_BROWSE_GROUP_ID: UInt32 = 512
SDP_ATTRIB_CORDLESS_EXTERNAL_NETWORK: UInt32 = 769
SDP_ATTRIB_FAX_CLASS_1_SUPPORT: UInt32 = 770
SDP_ATTRIB_FAX_CLASS_2_0_SUPPORT: UInt32 = 771
SDP_ATTRIB_FAX_CLASS_2_SUPPORT: UInt32 = 772
SDP_ATTRIB_FAX_AUDIO_FEEDBACK_SUPPORT: UInt32 = 773
SDP_ATTRIB_HEADSET_REMOTE_AUDIO_VOLUME_CONTROL: UInt32 = 770
SDP_ATTRIB_LAN_LPSUBNET: UInt32 = 512
SDP_ATTRIB_OBJECT_PUSH_SUPPORTED_FORMATS_LIST: UInt32 = 771
SDP_ATTRIB_SYNCH_SUPPORTED_DATA_STORES_LIST: UInt32 = 769
SDP_ATTRIB_SERVICE_VERSION: UInt32 = 768
SDP_ATTRIB_PAN_NETWORK_ADDRESS: UInt32 = 774
SDP_ATTRIB_PAN_WAP_GATEWAY: UInt32 = 775
SDP_ATTRIB_PAN_HOME_PAGE_URL: UInt32 = 776
SDP_ATTRIB_PAN_WAP_STACK_TYPE: UInt32 = 777
SDP_ATTRIB_PAN_SECURITY_DESCRIPTION: UInt32 = 778
SDP_ATTRIB_PAN_NET_ACCESS_TYPE: UInt32 = 779
SDP_ATTRIB_PAN_MAX_NET_ACCESS_RATE: UInt32 = 780
SDP_ATTRIB_IMAGING_SUPPORTED_CAPABILITIES: UInt32 = 784
SDP_ATTRIB_IMAGING_SUPPORTED_FEATURES: UInt32 = 785
SDP_ATTRIB_IMAGING_SUPPORTED_FUNCTIONS: UInt32 = 786
SDP_ATTRIB_IMAGING_TOTAL_DATA_CAPACITY: UInt32 = 787
SDP_ATTRIB_DI_SPECIFICATION_ID: UInt32 = 512
SDP_ATTRIB_DI_VENDOR_ID: UInt32 = 513
SDP_ATTRIB_DI_PRODUCT_ID: UInt32 = 514
SDP_ATTRIB_DI_VERSION: UInt32 = 515
SDP_ATTRIB_DI_PRIMARY_RECORD: UInt32 = 516
SDP_ATTRIB_DI_VENDOR_ID_SOURCE: UInt32 = 517
SDP_ATTRIB_HID_DEVICE_RELEASE_NUMBER: UInt32 = 512
SDP_ATTRIB_HID_PARSER_VERSION: UInt32 = 513
SDP_ATTRIB_HID_DEVICE_SUBCLASS: UInt32 = 514
SDP_ATTRIB_HID_COUNTRY_CODE: UInt32 = 515
SDP_ATTRIB_HID_VIRTUAL_CABLE: UInt32 = 516
SDP_ATTRIB_HID_RECONNECT_INITIATE: UInt32 = 517
SDP_ATTRIB_HID_DESCRIPTOR_LIST: UInt32 = 518
SDP_ATTRIB_HID_LANG_ID_BASE_LIST: UInt32 = 519
SDP_ATTRIB_HID_SDP_DISABLE: UInt32 = 520
SDP_ATTRIB_HID_BATTERY_POWER: UInt32 = 521
SDP_ATTRIB_HID_REMOTE_WAKE: UInt32 = 522
SDP_ATTRIB_HID_PROFILE_VERSION: UInt32 = 523
SDP_ATTRIB_HID_SUPERVISION_TIMEOUT: UInt32 = 524
SDP_ATTRIB_HID_NORMALLY_CONNECTABLE: UInt32 = 525
SDP_ATTRIB_HID_BOOT_DEVICE: UInt32 = 526
SDP_ATTRIB_HID_SSR_HOST_MAX_LATENCY: UInt32 = 527
SDP_ATTRIB_HID_SSR_HOST_MIN_TIMEOUT: UInt32 = 528
SDP_ATTRIB_A2DP_SUPPORTED_FEATURES: UInt32 = 785
SDP_ATTRIB_AVRCP_SUPPORTED_FEATURES: UInt32 = 785
SDP_ATTRIB_HFP_SUPPORTED_FEATURES: UInt32 = 785
AVRCP_SUPPORTED_FEATURES_CATEGORY_1: UInt32 = 1
AVRCP_SUPPORTED_FEATURES_CATEGORY_2: UInt32 = 2
AVRCP_SUPPORTED_FEATURES_CATEGORY_3: UInt32 = 4
AVRCP_SUPPORTED_FEATURES_CATEGORY_4: UInt32 = 8
AVRCP_SUPPORTED_FEATURES_CT_BROWSING: UInt32 = 64
AVRCP_SUPPORTED_FEATURES_CT_COVER_ART_IMAGE_PROPERTIES: UInt32 = 128
AVRCP_SUPPORTED_FEATURES_CT_COVER_ART_IMAGE: UInt32 = 256
AVRCP_SUPPORTED_FEATURES_CT_COVER_ART_LINKED_THUMBNAIL: UInt32 = 512
AVRCP_SUPPORTED_FEATURES_TG_PLAYER_APPLICATION_SETTINGS: UInt32 = 16
AVRCP_SUPPORTED_FEATURES_TG_GROUP_NAVIGATION: UInt32 = 32
AVRCP_SUPPORTED_FEATURES_TG_BROWSING: UInt32 = 64
AVRCP_SUPPORTED_FEATURES_TG_MULTIPLE_PLAYER_APPLICATIONS: UInt32 = 128
AVRCP_SUPPORTED_FEATURES_TG_COVER_ART: UInt32 = 256
A2DP_SINK_SUPPORTED_FEATURES_HEADPHONE: UInt32 = 1
A2DP_SINK_SUPPORTED_FEATURES_SPEAKER: UInt32 = 2
A2DP_SINK_SUPPORTED_FEATURES_RECORDER: UInt32 = 4
A2DP_SINK_SUPPORTED_FEATURES_AMPLIFIER: UInt32 = 8
A2DP_SOURCE_SUPPORTED_FEATURES_PLAYER: UInt32 = 1
A2DP_SOURCE_SUPPORTED_FEATURES_MICROPHONE: UInt32 = 2
A2DP_SOURCE_SUPPORTED_FEATURES_TUNER: UInt32 = 4
A2DP_SOURCE_SUPPORTED_FEATURES_MIXER: UInt32 = 8
CORDLESS_EXTERNAL_NETWORK_PSTN: UInt32 = 1
CORDLESS_EXTERNAL_NETWORK_ISDN: UInt32 = 2
CORDLESS_EXTERNAL_NETWORK_GSM: UInt32 = 3
CORDLESS_EXTERNAL_NETWORK_CDMA: UInt32 = 4
CORDLESS_EXTERNAL_NETWORK_ANALOG_CELLULAR: UInt32 = 5
CORDLESS_EXTERNAL_NETWORK_PACKET_SWITCHED: UInt32 = 6
CORDLESS_EXTERNAL_NETWORK_OTHER: UInt32 = 7
OBJECT_PUSH_FORMAT_VCARD_2_1: UInt32 = 1
OBJECT_PUSH_FORMAT_VCARD_3_0: UInt32 = 2
OBJECT_PUSH_FORMAT_VCAL_1_0: UInt32 = 3
OBJECT_PUSH_FORMAT_ICAL_2_0: UInt32 = 4
OBJECT_PUSH_FORMAT_VNOTE: UInt32 = 5
OBJECT_PUSH_FORMAT_VMESSAGE: UInt32 = 6
OBJECT_PUSH_FORMAT_ANY: UInt32 = 255
SYNCH_DATA_STORE_PHONEBOOK: UInt32 = 1
SYNCH_DATA_STORE_CALENDAR: UInt32 = 3
SYNCH_DATA_STORE_NOTES: UInt32 = 5
SYNCH_DATA_STORE_MESSAGES: UInt32 = 6
DI_VENDOR_ID_SOURCE_BLUETOOTH_SIG: UInt32 = 1
DI_VENDOR_ID_SOURCE_USB_IF: UInt32 = 2
PSM_SDP: UInt32 = 1
PSM_RFCOMM: UInt32 = 3
PSM_TCS_BIN: UInt32 = 5
PSM_TCS_BIN_CORDLESS: UInt32 = 7
PSM_BNEP: UInt32 = 15
PSM_HID_CONTROL: UInt32 = 17
PSM_HID_INTERRUPT: UInt32 = 19
PSM_UPNP: UInt32 = 21
PSM_AVCTP: UInt32 = 23
PSM_AVDTP: UInt32 = 25
PSM_AVCTP_BROWSE: UInt32 = 27
PSM_UDI_C_PLANE: UInt32 = 29
PSM_ATT: UInt32 = 31
PSM_3DSP: UInt32 = 33
PSM_LE_IPSP: UInt32 = 35
STR_ADDR_FMTA: String = '(%02x:%02x:%02x:%02x:%02x:%02x)'
STR_ADDR_FMTW: String = '(%02x:%02x:%02x:%02x:%02x:%02x)'
STR_ADDR_SHORT_FMTA: String = '%04x%08x'
STR_ADDR_SHORT_FMTW: String = '%04x%08x'
STR_USBHCI_CLASS_HARDWAREIDA: String = 'USB\\Class_E0&SubClass_01&Prot_01'
STR_USBHCI_CLASS_HARDWAREIDW: String = 'USB\\Class_E0&SubClass_01&Prot_01'
STR_ADDR_FMT: String = '(%02x:%02x:%02x:%02x:%02x:%02x)'
STR_ADDR_SHORT_FMT: String = '%04x%08x'
STR_USBHCI_CLASS_HARDWAREID: String = 'USB\\Class_E0&SubClass_01&Prot_01'
BTH_IOCTL_BASE: UInt32 = 0
SDP_CONNECT_CACHE: UInt32 = 1
SDP_CONNECT_ALLOW_PIN: UInt32 = 2
SDP_REQUEST_TO_DEFAULT: UInt32 = 0
SDP_REQUEST_TO_MIN: UInt32 = 10
SDP_REQUEST_TO_MAX: UInt32 = 45
SERVICE_OPTION_DO_NOT_PUBLISH: UInt32 = 2
SERVICE_OPTION_NO_PUBLIC_BROWSE: UInt32 = 4
SERVICE_OPTION_DO_NOT_PUBLISH_EIR: UInt32 = 8
SERVICE_SECURITY_USE_DEFAULTS: UInt32 = 0
SERVICE_SECURITY_NONE: UInt32 = 1
SERVICE_SECURITY_AUTHORIZE: UInt32 = 2
SERVICE_SECURITY_AUTHENTICATE: UInt32 = 4
SERVICE_SECURITY_ENCRYPT_REQUIRED: UInt32 = 16
SERVICE_SECURITY_ENCRYPT_OPTIONAL: UInt32 = 32
SERVICE_SECURITY_DISABLED: UInt32 = 268435456
SERVICE_SECURITY_NO_ASK: UInt32 = 536870912
SDP_SEARCH_NO_PARSE_CHECK: UInt32 = 1
SDP_SEARCH_NO_FORMAT_CHECK: UInt32 = 2
BTH_HOST_FEATURE_ENHANCED_RETRANSMISSION_MODE: UInt64 = 1
BTH_HOST_FEATURE_STREAMING_MODE: UInt64 = 2
BTH_HOST_FEATURE_LOW_ENERGY: UInt64 = 4
BTH_HOST_FEATURE_SCO_HCI: UInt64 = 8
BTH_HOST_FEATURE_SCO_HCIBYPASS: UInt64 = 16
BLUETOOTH_MAX_NAME_SIZE: UInt32 = 248
BLUETOOTH_MAX_PASSKEY_SIZE: UInt32 = 16
BLUETOOTH_MAX_PASSKEY_BUFFER_SIZE: UInt32 = 17
BLUETOOTH_MAX_SERVICE_NAME_SIZE: UInt32 = 256
BLUETOOTH_DEVICE_NAME_SIZE: UInt32 = 256
BLUETOOTH_SERVICE_DISABLE: UInt32 = 0
BLUETOOTH_SERVICE_ENABLE: UInt32 = 1
GUID_BLUETOOTHLE_DEVICE_INTERFACE: Guid = Guid('{781aee18-7733-4ce4-add0-91f41c67b592}')
GUID_BLUETOOTH_GATT_SERVICE_DEVICE_INTERFACE: Guid = Guid('{6e3bb679-4372-40c8-9eaa-4509df260cd8}')
BTH_LE_ATT_BLUETOOTH_BASE_GUID: Guid = Guid('{00000000-0000-1000-8000-00805f9b34fb}')
BTH_LE_SERVICE_GAP: UInt32 = 6144
BTH_LE_SERVICE_GATT: UInt32 = 6145
BTH_LE_GATT_ATTRIBUTE_TYPE_PRIMARY_SERVICE: UInt32 = 10240
BTH_LE_GATT_ATTRIBUTE_TYPE_SECONDARY_SERVICE: UInt32 = 10241
BTH_LE_GATT_ATTRIBUTE_TYPE_INCLUDE: UInt32 = 10242
BTH_LE_GATT_ATTRIBUTE_TYPE_CHARACTERISTIC: UInt32 = 10243
BTH_LE_GATT_CHARACTERISTIC_DESCRIPTOR_EXTENDED_PROPERTIES: UInt32 = 10496
BTH_LE_GATT_CHARACTERISTIC_DESCRIPTOR_USER_DESCRIPTION: UInt32 = 10497
BTH_LE_GATT_CHARACTERISTIC_DESCRIPTOR_CLIENT_CONFIGURATION: UInt32 = 10498
BTH_LE_GATT_CHARACTERISTIC_DESCRIPTOR_SERVER_CONFIGURATION: UInt32 = 10499
BTH_LE_GATT_CHARACTERISTIC_DESCRIPTOR_FORMAT: UInt32 = 10500
BTH_LE_GATT_CHARACTERISTIC_DESCRIPTOR_AGGREGATE_FORMAT: UInt32 = 10501
BTH_LE_GATT_CHARACTERISTIC_TYPE_DEVICE_NAME: UInt32 = 10752
BTH_LE_GATT_CHARACTERISTIC_TYPE_APPEARANCE: UInt32 = 10753
BTH_LE_GATT_CHARACTERISTIC_TYPE_PERIPHERAL_PRIVACY_FLAG: UInt32 = 10754
BTH_LE_GATT_CHARACTERISTIC_TYPE_RECONNECTION_ADDRESS: UInt32 = 10755
BTH_LE_GATT_CHARACTERISTIC_TYPE_PERIPHERAL_PREFERED_CONNECTION_PARAMETER: UInt32 = 10756
BTH_LE_GATT_CHARACTERISTIC_TYPE_SERVICE_CHANGED: UInt32 = 10757
BTH_LE_GAP_APPEARANCE_CATEGORY_OFFSET: UInt32 = 6
BTH_LE_GAP_APPEARANCE_CATEGORY_MASK: UInt32 = 1023
BTH_LE_GAP_APPEARANCE_SUB_CATEGORY_MASK: UInt32 = 63
BTH_LE_GAP_APPEARANCE_CATEGORY_UNCATEGORIZED: UInt32 = 0
BTH_LE_GAP_APPEARANCE_CATEGORY_PHONE: UInt32 = 1
BTH_LE_GAP_APPEARANCE_CATEGORY_COMPUTER: UInt32 = 2
BTH_LE_GAP_APPEARANCE_CATEGORY_WATCH: UInt32 = 3
BTH_LE_GAP_APPEARANCE_CATEGORY_CLOCK: UInt32 = 4
BTH_LE_GAP_APPEARANCE_CATEGORY_DISPLAY: UInt32 = 5
BTH_LE_GAP_APPEARANCE_CATEGORY_REMOTE_CONTROL: UInt32 = 6
BTH_LE_GAP_APPEARANCE_CATEGORY_EYE_GLASSES: UInt32 = 7
BTH_LE_GAP_APPEARANCE_CATEGORY_TAG: UInt32 = 8
BTH_LE_GAP_APPEARANCE_CATEGORY_KEYRING: UInt32 = 9
BTH_LE_GAP_APPEARANCE_CATEGORY_MEDIA_PLAYER: UInt32 = 10
BTH_LE_GAP_APPEARANCE_CATEGORY_BARCODE_SCANNER: UInt32 = 11
BTH_LE_GAP_APPEARANCE_CATEGORY_THERMOMETER: UInt32 = 12
BTH_LE_GAP_APPEARANCE_CATEGORY_HEART_RATE: UInt32 = 13
BTH_LE_GAP_APPEARANCE_CATEGORY_BLOOD_PRESSURE: UInt32 = 14
BTH_LE_GAP_APPEARANCE_CATEGORY_HID: UInt32 = 15
BTH_LE_GAP_APPEARANCE_CATEGORY_GLUCOSE_METER: UInt32 = 16
BTH_LE_GAP_APPEARANCE_CATEGORY_RUNNING_WALKING_SENSOR: UInt32 = 17
BTH_LE_GAP_APPEARANCE_CATEGORY_CYCLING: UInt32 = 18
BTH_LE_GAP_APPEARANCE_CATEGORY_CONTROL_DEVICE: UInt32 = 19
BTH_LE_GAP_APPEARANCE_CATEGORY_NETWORK_DEVICE: UInt32 = 20
BTH_LE_GAP_APPEARANCE_CATEGORY_SENSOR: UInt32 = 21
BTH_LE_GAP_APPEARANCE_CATEGORY_LIGHT_FIXTURES: UInt32 = 22
BTH_LE_GAP_APPEARANCE_CATEGORY_FAN: UInt32 = 23
BTH_LE_GAP_APPEARANCE_CATEGORY_HVAC: UInt32 = 24
BTH_LE_GAP_APPEARANCE_CATEGORY_AIR_CONDITIONING: UInt32 = 25
BTH_LE_GAP_APPEARANCE_CATEGORY_HUMIDIFIER: UInt32 = 26
BTH_LE_GAP_APPEARANCE_CATEGORY_HEATING: UInt32 = 27
BTH_LE_GAP_APPEARANCE_CATEGORY_ACCESS_CONTROL: UInt32 = 28
BTH_LE_GAP_APPEARANCE_CATEGORY_MOTORIZED_DEVICE: UInt32 = 29
BTH_LE_GAP_APPEARANCE_CATEGORY_POWER_DEVICE: UInt32 = 30
BTH_LE_GAP_APPEARANCE_CATEGORY_LIGHT_SOURCE: UInt32 = 31
BTH_LE_GAP_APPEARANCE_CATEGORY_WINDOW_COVERING: UInt32 = 32
BTH_LE_GAP_APPEARANCE_CATEGORY_AUDIO_SINK: UInt32 = 33
BTH_LE_GAP_APPEARANCE_CATEGORY_AUDIO_SOURCE: UInt32 = 34
BTH_LE_GAP_APPEARANCE_CATEGORY_MOTORIZED_VEHICLE: UInt32 = 35
BTH_LE_GAP_APPEARANCE_CATEGORY_DOMESTIC_APPLIANCE: UInt32 = 36
BTH_LE_GAP_APPEARANCE_CATEGORY_WEARABLE_AUDIO_DEVICE: UInt32 = 37
BTH_LE_GAP_APPEARANCE_CATEGORY_AIRCRAFT: UInt32 = 38
BTH_LE_GAP_APPEARANCE_CATEGORY_AV_EQUIPMENT: UInt32 = 39
BTH_LE_GAP_APPEARANCE_CATEGORY_DISPLAY_EQUIPMENT: UInt32 = 40
BTH_LE_GAP_APPEARANCE_CATEGORY_HEARING_AID: UInt32 = 41
BTH_LE_GAP_APPEARANCE_CATEGORY_GAMING: UInt32 = 42
BTH_LE_GAP_APPEARANCE_CATEGORY_SIGNAGE: UInt32 = 43
BTH_LE_GAP_APPEARANCE_CATEGORY_PLUSE_OXIMETER: UInt32 = 49
BTH_LE_GAP_APPEARANCE_CATEGORY_WEIGHT_SCALE: UInt32 = 50
BTH_LE_GAP_APPEARANCE_CATEGORY_PERSONAL_MOBILITY_DEVICE: UInt32 = 51
BTH_LE_GAP_APPEARANCE_CATEGORY_CONTINUOUS_GLUCOSE_MONITOR: UInt32 = 52
BTH_LE_GAP_APPEARANCE_CATEGORY_INSULIN_PUMP: UInt32 = 53
BTH_LE_GAP_APPEARANCE_CATEGORY_MEDICATION_DELIVERY: UInt32 = 54
BTH_LE_GAP_APPEARANCE_CATEGORY_OUTDOOR_SPORTS_ACTIVITY: UInt32 = 81
BTH_LE_GAP_APPEARANCE_SUBCATEGORY_GENERIC: UInt32 = 0
BTH_LE_GAP_APPEARANCE_WATCH_SUBCATEGORY_SPORTS_WATCH: UInt32 = 1
BTH_LE_GAP_APPEARANCE_THERMOMETER_SUBCATEGORY_EAR: UInt32 = 1
BTH_LE_GAP_APPEARANCE_HEART_RATE_SUBCATEGORY_HEART_RATE_BELT: UInt32 = 1
BTH_LE_GAP_APPEARANCE_BLOOD_PRESSURE_SUBCATEGORY_ARM: UInt32 = 1
BTH_LE_GAP_APPEARANCE_BLOOD_PRESSURE_SUBCATEGORY_WRIST: UInt32 = 2
BTH_LE_GAP_APPEARANCE_HID_SUBCATEGORY_KEYBOARD: UInt32 = 1
BTH_LE_GAP_APPEARANCE_HID_SUBCATEGORY_MOUSE: UInt32 = 2
BTH_LE_GAP_APPEARANCE_HID_SUBCATEGORY_JOYSTICK: UInt32 = 3
BTH_LE_GAP_APPEARANCE_HID_SUBCATEGORY_GAMEPAD: UInt32 = 4
BTH_LE_GAP_APPEARANCE_HID_SUBCATEGORY_DIGITIZER_TABLET: UInt32 = 5
BTH_LE_GAP_APPEARANCE_HID_SUBCATEGORY_CARD_READER: UInt32 = 6
BTH_LE_GAP_APPEARANCE_HID_SUBCATEGORY_DIGITAL_PEN: UInt32 = 7
BTH_LE_GAP_APPEARANCE_HID_SUBCATEGORY_BARCODE_SCANNER: UInt32 = 8
BTH_LE_GAP_APPEARANCE_RUNNING_WALKING_SENSOR_SUBCATEGORY_IN_SHOE: UInt32 = 1
BTH_LE_GAP_APPEARANCE_RUNNING_WALKING_SENSOR_SUBCATEGORY_ON_SHOE: UInt32 = 2
BTH_LE_GAP_APPEARANCE_RUNNING_WALKING_SENSOR_SUBCATEGORY_ON_HIP: UInt32 = 3
BTH_LE_GAP_APPEARANCE_CYCLING_SUBCATEGORY_CYCLING_COMPUTER: UInt32 = 1
BTH_LE_GAP_APPEARANCE_CYCLING_SUBCATEGORY_SPEED_SENSOR: UInt32 = 2
BTH_LE_GAP_APPEARANCE_CYCLING_SUBCATEGORY_CADENCE_SENSOR: UInt32 = 3
BTH_LE_GAP_APPEARANCE_CYCLING_SUBCATEGORY_POWER_SENSOR: UInt32 = 4
BTH_LE_GAP_APPEARANCE_CYCLING_SUBCATEGORY_SPEED_AND_CADENCE_SENSOR: UInt32 = 5
BTH_LE_GAP_APPEARANCE_AUDIO_SINK_SUBCATEGORY_STANDALONE_SPEAKER: UInt32 = 1
BTH_LE_GAP_APPEARANCE_AUDIO_SINK_SUBCATEGORY_SOUNDBAR: UInt32 = 2
BTH_LE_GAP_APPEARANCE_AUDIO_SINK_SUBCATEGORY_BOOKSHELF_SPEAKER: UInt32 = 3
BTH_LE_GAP_APPEARANCE_AUDIO_SINK_SUBCATEGORY_STANDMOUNTED_SPEAKER: UInt32 = 4
BTH_LE_GAP_APPEARANCE_AUDIO_SINK_SUBCATEGORY_SPEAKERPHONE: UInt32 = 5
BTH_LE_GAP_APPEARANCE_AUDIO_SOURCE_SUBCATEGORY_MICROPHONE: UInt32 = 1
BTH_LE_GAP_APPEARANCE_AUDIO_SOURCE_SUBCATEGORY_ALARM: UInt32 = 2
BTH_LE_GAP_APPEARANCE_AUDIO_SOURCE_SUBCATEGORY_BELL: UInt32 = 3
BTH_LE_GAP_APPEARANCE_AUDIO_SOURCE_SUBCATEGORY_HORN: UInt32 = 4
BTH_LE_GAP_APPEARANCE_AUDIO_SOURCE_SUBCATEGORY_BROADCASTING_DEVICE: UInt32 = 5
BTH_LE_GAP_APPEARANCE_AUDIO_SOURCE_SUBCATEGORY_SERVICE_DESK: UInt32 = 6
BTH_LE_GAP_APPEARANCE_AUDIO_SOURCE_SUBCATEGORY_KIOSK: UInt32 = 7
BTH_LE_GAP_APPEARANCE_AUDIO_SOURCE_SUBCATEGORY_BROADCASTING_ROOM: UInt32 = 8
BTH_LE_GAP_APPEARANCE_AUDIO_SOURCE_SUBCATEGORY_AUDITORIUM: UInt32 = 9
BTH_LE_GAP_APPEARANCE_WEARABLE_AUDIO_DEVICE_SUBCATEGORY_EARBUD: UInt32 = 1
BTH_LE_GAP_APPEARANCE_WEARABLE_AUDIO_DEVICE_SUBCATEGORY_HEADSET: UInt32 = 2
BTH_LE_GAP_APPEARANCE_WEARABLE_AUDIO_DEVICE_SUBCATEGORY_HEADPHONES: UInt32 = 3
BTH_LE_GAP_APPEARANCE_WEARABLE_AUDIO_DEVICE_SUBCATEGORY_NECKBAND: UInt32 = 4
BTH_LE_GAP_APPEARANCE_HEARING_AID_SUBCATEGORY_IN_EAR_HEARING_AID: UInt32 = 1
BTH_LE_GAP_APPEARANCE_HEARING_AID_SUBCATEGORY_BEHIND_EAR_HEARING_AID: UInt32 = 2
BTH_LE_GAP_APPEARANCE_HEARING_AID_SUBCATEGORY_COCHLEAR_IMPLANT: UInt32 = 3
BTH_LE_GAP_APPEARANCE_PULSE_OXIMETER_SUBCATEGORY_FINGERTIP: UInt32 = 1
BTH_LE_GAP_APPEARANCE_PULSE_OXIMETER_SUBCATEGORY_WRIST_WORN: UInt32 = 2
BTH_LE_GAP_APPEARANCE_OUTDOOR_SPORTS_ACTIVITY_SUBCATEGORY_LOCATION_DISPLAY_DEVICE: UInt32 = 1
BTH_LE_GAP_APPEARANCE_OUTDOOR_SPORTS_ACTIVITY_SUBCATEGORY_LOCATION_NAVIGATION_DISPLAY_DEVICE: UInt32 = 2
BTH_LE_GAP_APPEARANCE_OUTDOOR_SPORTS_ACTIVITY_SUBCATEGORY_LOCATION_POD: UInt32 = 3
BTH_LE_GAP_APPEARANCE_OUTDOOR_SPORTS_ACTIVITY_SUBCATEGORY_LOCATION_NAVIGATION_POD: UInt32 = 4
BTH_LE_GATT_DEFAULT_MAX_INCLUDED_SERVICES_DEPTH: UInt32 = 3
BTH_LE_ATT_TRANSACTION_TIMEOUT: UInt32 = 30
BTH_LE_ATT_MAX_VALUE_SIZE: UInt32 = 512
BTH_LE_ATT_CID: UInt32 = 4
BTHLEENUM_ATT_MTU_MIN: UInt32 = 23
BTHLEENUM_ATT_MTU_MAX: UInt32 = 65535
BTHLEENUM_ATT_MTU_DEFAULT: UInt32 = 23
BTHLEENUM_ATT_MTU_INITIAL_NEGOTIATION: UInt32 = 525
BTH_LE_ERROR_INVALID_HANDLE: UInt32 = 1
BTH_LE_ERROR_READ_NOT_PERMITTED: UInt32 = 2
BTH_LE_ERROR_WRITE_NOT_PERMITTED: UInt32 = 3
BTH_LE_ERROR_INVALID_PDU: UInt32 = 4
BTH_LE_ERROR_INSUFFICIENT_AUTHENTICATION: UInt32 = 5
BTH_LE_ERROR_REQUEST_NOT_SUPPORTED: UInt32 = 6
BTH_LE_ERROR_INVALID_OFFSET: UInt32 = 7
BTH_LE_ERROR_INSUFFICIENT_AUTHORIZATION: UInt32 = 8
BTH_LE_ERROR_PREPARE_QUEUE_FULL: UInt32 = 9
BTH_LE_ERROR_ATTRIBUTE_NOT_FOUND: UInt32 = 10
BTH_LE_ERROR_ATTRIBUTE_NOT_LONG: UInt32 = 11
BTH_LE_ERROR_INSUFFICIENT_ENCRYPTION_KEY_SIZE: UInt32 = 12
BTH_LE_ERROR_INVALID_ATTRIBUTE_VALUE_LENGTH: UInt32 = 13
BTH_LE_ERROR_UNLIKELY: UInt32 = 14
BTH_LE_ERROR_INSUFFICIENT_ENCRYPTION: UInt32 = 15
BTH_LE_ERROR_UNSUPPORTED_GROUP_TYPE: UInt32 = 16
BTH_LE_ERROR_INSUFFICIENT_RESOURCES: UInt32 = 17
BTH_LE_ERROR_UNKNOWN: UInt32 = 4096
BLUETOOTH_GATT_FLAG_NONE: UInt32 = 0
BLUETOOTH_GATT_FLAG_CONNECTION_ENCRYPTED: UInt32 = 1
BLUETOOTH_GATT_FLAG_CONNECTION_AUTHENTICATED: UInt32 = 2
BLUETOOTH_GATT_FLAG_FORCE_READ_FROM_DEVICE: UInt32 = 4
BLUETOOTH_GATT_FLAG_FORCE_READ_FROM_CACHE: UInt32 = 8
BLUETOOTH_GATT_FLAG_SIGNED_WRITE: UInt32 = 16
BLUETOOTH_GATT_FLAG_WRITE_WITHOUT_RESPONSE: UInt32 = 32
BLUETOOTH_GATT_FLAG_RETURN_ALL: UInt32 = 64
BT_PORT_MIN: UInt32 = 1
BT_PORT_MAX: UInt32 = 65535
BT_PORT_DYN_FIRST: UInt32 = 4097
AF_BTH: UInt16 = 32
PF_BTH: UInt16 = 32
NS_BTH: UInt32 = 16
SVCID_BTH_PROVIDER: Guid = Guid('{06aa63e0-7d60-41ff-afb2-3ee6d2d9392d}')
BTH_ADDR_STRING_SIZE: UInt32 = 12
BTHPROTO_RFCOMM: UInt32 = 3
BTHPROTO_L2CAP: UInt32 = 256
SOL_RFCOMM: UInt32 = 3
SOL_L2CAP: UInt32 = 256
SOL_SDP: UInt32 = 257
SO_BTH_AUTHENTICATE: UInt32 = 2147483649
SO_BTH_ENCRYPT: UInt32 = 2
SO_BTH_MTU: UInt32 = 2147483655
SO_BTH_MTU_MAX: UInt32 = 2147483656
SO_BTH_MTU_MIN: UInt32 = 2147483658
RFCOMM_MAX_MTU: UInt32 = 1011
RFCOMM_MIN_MTU: UInt32 = 23
BTH_SDP_VERSION: UInt32 = 1
SDP_DEFAULT_INQUIRY_SECONDS: UInt32 = 6
SDP_MAX_INQUIRY_SECONDS: UInt32 = 60
SDP_DEFAULT_INQUIRY_MAX_RESPONSES: UInt32 = 255
SDP_SERVICE_SEARCH_REQUEST: UInt32 = 1
SDP_SERVICE_ATTRIBUTE_REQUEST: UInt32 = 2
SDP_SERVICE_SEARCH_ATTRIBUTE_REQUEST: UInt32 = 3
BTHNS_RESULT_DEVICE_CONNECTED: UInt32 = 65536
BTHNS_RESULT_DEVICE_REMEMBERED: UInt32 = 131072
BTHNS_RESULT_DEVICE_AUTHENTICATED: UInt32 = 262144
RLS_ERROR: UInt32 = 1
RLS_OVERRUN: UInt32 = 2
RLS_PARITY: UInt32 = 4
RLS_FRAMING: UInt32 = 8
RPN_BAUD_2400: UInt32 = 0
RPN_BAUD_4800: UInt32 = 1
RPN_BAUD_7200: UInt32 = 2
RPN_BAUD_9600: UInt32 = 3
RPN_BAUD_19200: UInt32 = 4
RPN_BAUD_38400: UInt32 = 5
RPN_BAUD_57600: UInt32 = 6
RPN_BAUD_115200: UInt32 = 7
RPN_BAUD_230400: UInt32 = 8
RPN_DATA_5: UInt32 = 0
RPN_DATA_6: UInt32 = 1
RPN_DATA_7: UInt32 = 2
RPN_DATA_8: UInt32 = 3
RPN_STOP_1: UInt32 = 0
RPN_STOP_1_5: UInt32 = 4
RPN_PARITY_NONE: UInt32 = 0
RPN_PARITY_ODD: UInt32 = 8
RPN_PARITY_EVEN: UInt32 = 24
RPN_PARITY_MARK: UInt32 = 40
RPN_PARITY_SPACE: UInt32 = 56
RPN_FLOW_X_IN: UInt32 = 1
RPN_FLOW_X_OUT: UInt32 = 2
RPN_FLOW_RTR_IN: UInt32 = 4
RPN_FLOW_RTR_OUT: UInt32 = 8
RPN_FLOW_RTC_IN: UInt32 = 16
RPN_FLOW_RTC_OUT: UInt32 = 32
RPN_PARAM_BAUD: UInt32 = 1
RPN_PARAM_DATA: UInt32 = 2
RPN_PARAM_STOP: UInt32 = 4
RPN_PARAM_PARITY: UInt32 = 8
RPN_PARAM_P_TYPE: UInt32 = 16
RPN_PARAM_XON: UInt32 = 32
RPN_PARAM_XOFF: UInt32 = 64
RPN_PARAM_X_IN: UInt32 = 1
RPN_PARAM_X_OUT: UInt32 = 2
RPN_PARAM_RTR_IN: UInt32 = 4
RPN_PARAM_RTR_OUT: UInt32 = 8
RPN_PARAM_RTC_IN: UInt32 = 16
RPN_PARAM_RTC_OUT: UInt32 = 32
RFCOMM_CMD_NONE: UInt32 = 0
RFCOMM_CMD_MSC: UInt32 = 1
RFCOMM_CMD_RLS: UInt32 = 2
RFCOMM_CMD_RPN: UInt32 = 3
RFCOMM_CMD_RPN_REQUEST: UInt32 = 4
RFCOMM_CMD_RPN_RESPONSE: UInt32 = 5
@winfunctype('BluetoothApis.dll')
def BluetoothFindFirstRadio(pbtfrp: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_FIND_RADIO_PARAMS), phRadio: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Devices.Bluetooth.HBLUETOOTH_RADIO_FIND: ...
@winfunctype('BluetoothApis.dll')
def BluetoothFindNextRadio(hFind: win32more.Windows.Win32.Devices.Bluetooth.HBLUETOOTH_RADIO_FIND, phRadio: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('BluetoothApis.dll')
def BluetoothFindRadioClose(hFind: win32more.Windows.Win32.Devices.Bluetooth.HBLUETOOTH_RADIO_FIND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGetRadioInfo(hRadio: win32more.Windows.Win32.Foundation.HANDLE, pRadioInfo: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_RADIO_INFO)) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothFindFirstDevice(pbtsp: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_SEARCH_PARAMS), pbtdi: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO)) -> win32more.Windows.Win32.Devices.Bluetooth.HBLUETOOTH_DEVICE_FIND: ...
@winfunctype('BluetoothApis.dll')
def BluetoothFindNextDevice(hFind: win32more.Windows.Win32.Devices.Bluetooth.HBLUETOOTH_DEVICE_FIND, pbtdi: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('BluetoothApis.dll')
def BluetoothFindDeviceClose(hFind: win32more.Windows.Win32.Devices.Bluetooth.HBLUETOOTH_DEVICE_FIND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGetDeviceInfo(hRadio: win32more.Windows.Win32.Foundation.HANDLE, pbtdi: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO)) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothUpdateDeviceRecord(pbtdi: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO)) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothRemoveDevice(pAddress: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_ADDRESS)) -> UInt32: ...
@winfunctype('bthprops.cpl')
def BluetoothSelectDevices(pbtsdp: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_SELECT_DEVICE_PARAMS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('bthprops.cpl')
def BluetoothSelectDevicesFree(pbtsdp: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_SELECT_DEVICE_PARAMS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('bthprops.cpl')
def BluetoothDisplayDeviceProperties(hwndParent: win32more.Windows.Win32.Foundation.HWND, pbtdi: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('bthprops.cpl')
def BluetoothAuthenticateDevice(hwndParent: win32more.Windows.Win32.Foundation.HWND, hRadio: win32more.Windows.Win32.Foundation.HANDLE, pbtbi: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO), pszPasskey: win32more.Windows.Win32.Foundation.PWSTR, ulPasskeyLength: UInt32) -> UInt32: ...
@winfunctype('bthprops.cpl')
def BluetoothAuthenticateDeviceEx(hwndParentIn: win32more.Windows.Win32.Foundation.HWND, hRadioIn: win32more.Windows.Win32.Foundation.HANDLE, pbtdiInout: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO), pbtOobData: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_OOB_DATA_INFO), authenticationRequirement: win32more.Windows.Win32.Devices.Bluetooth.AUTHENTICATION_REQUIREMENTS) -> UInt32: ...
@winfunctype('bthprops.cpl')
def BluetoothAuthenticateMultipleDevices(hwndParent: win32more.Windows.Win32.Foundation.HWND, hRadio: win32more.Windows.Win32.Foundation.HANDLE, cDevices: UInt32, rgbtdi: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO)) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothSetServiceState(hRadio: win32more.Windows.Win32.Foundation.HANDLE, pbtdi: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO), pGuidService: POINTER(Guid), dwServiceFlags: UInt32) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothEnumerateInstalledServices(hRadio: win32more.Windows.Win32.Foundation.HANDLE, pbtdi: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO), pcServiceInout: POINTER(UInt32), pGuidServices: POINTER(Guid)) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothEnableDiscovery(hRadio: win32more.Windows.Win32.Foundation.HANDLE, fEnabled: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('BluetoothApis.dll')
def BluetoothIsDiscoverable(hRadio: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('BluetoothApis.dll')
def BluetoothEnableIncomingConnections(hRadio: win32more.Windows.Win32.Foundation.HANDLE, fEnabled: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('BluetoothApis.dll')
def BluetoothIsConnectable(hRadio: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('BluetoothApis.dll')
def BluetoothRegisterForAuthentication(pbtdi: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO), phRegHandle: POINTER(IntPtr), pfnCallback: win32more.Windows.Win32.Devices.Bluetooth.PFN_AUTHENTICATION_CALLBACK, pvParam: VoidPtr) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothRegisterForAuthenticationEx(pbtdiIn: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO), phRegHandleOut: POINTER(IntPtr), pfnCallbackIn: win32more.Windows.Win32.Devices.Bluetooth.PFN_AUTHENTICATION_CALLBACK_EX, pvParam: VoidPtr) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothUnregisterAuthentication(hRegHandle: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('BluetoothApis.dll')
def BluetoothSendAuthenticationResponse(hRadio: win32more.Windows.Win32.Foundation.HANDLE, pbtdi: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO), pszPasskey: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothSendAuthenticationResponseEx(hRadioIn: win32more.Windows.Win32.Foundation.HANDLE, pauthResponse: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATE_RESPONSE)) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothSdpGetElementData(pSdpStream: POINTER(Byte), cbSdpStreamLength: UInt32, pData: POINTER(win32more.Windows.Win32.Devices.Bluetooth.SDP_ELEMENT_DATA)) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothSdpGetContainerElementData(pContainerStream: POINTER(Byte), cbContainerLength: UInt32, pElement: POINTER(IntPtr), pData: POINTER(win32more.Windows.Win32.Devices.Bluetooth.SDP_ELEMENT_DATA)) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothSdpGetAttributeValue(pRecordStream: POINTER(Byte), cbRecordLength: UInt32, usAttributeId: UInt16, pAttributeData: POINTER(win32more.Windows.Win32.Devices.Bluetooth.SDP_ELEMENT_DATA)) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothSdpGetString(pRecordStream: POINTER(Byte), cbRecordLength: UInt32, pStringData: POINTER(win32more.Windows.Win32.Devices.Bluetooth.SDP_STRING_TYPE_DATA), usStringOffset: UInt16, pszString: win32more.Windows.Win32.Foundation.PWSTR, pcchStringLength: POINTER(UInt32)) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothSdpEnumAttributes(pSDPStream: POINTER(Byte), cbStreamSize: UInt32, pfnCallback: win32more.Windows.Win32.Devices.Bluetooth.PFN_BLUETOOTH_ENUM_ATTRIBUTES_CALLBACK, pvParam: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('BluetoothApis.dll')
def BluetoothSetLocalServiceInfo(hRadioIn: win32more.Windows.Win32.Foundation.HANDLE, pClassGuid: POINTER(Guid), ulInstance: UInt32, pServiceInfoIn: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_LOCAL_SERVICE_INFO)) -> UInt32: ...
@winfunctype('BluetoothApis.dll')
def BluetoothIsVersionAvailable(MajorVersion: Byte, MinorVersion: Byte) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTGetServices(hDevice: win32more.Windows.Win32.Foundation.HANDLE, ServicesBufferCount: UInt16, ServicesBuffer: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_SERVICE), ServicesBufferActual: POINTER(UInt16), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTGetIncludedServices(hDevice: win32more.Windows.Win32.Foundation.HANDLE, ParentService: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_SERVICE), IncludedServicesBufferCount: UInt16, IncludedServicesBuffer: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_SERVICE), IncludedServicesBufferActual: POINTER(UInt16), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTGetCharacteristics(hDevice: win32more.Windows.Win32.Foundation.HANDLE, Service: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_SERVICE), CharacteristicsBufferCount: UInt16, CharacteristicsBuffer: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_CHARACTERISTIC), CharacteristicsBufferActual: POINTER(UInt16), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTGetDescriptors(hDevice: win32more.Windows.Win32.Foundation.HANDLE, Characteristic: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_CHARACTERISTIC), DescriptorsBufferCount: UInt16, DescriptorsBuffer: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR), DescriptorsBufferActual: POINTER(UInt16), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTGetCharacteristicValue(hDevice: win32more.Windows.Win32.Foundation.HANDLE, Characteristic: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_CHARACTERISTIC), CharacteristicValueDataSize: UInt32, CharacteristicValue: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_CHARACTERISTIC_VALUE), CharacteristicValueSizeRequired: POINTER(UInt16), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTGetDescriptorValue(hDevice: win32more.Windows.Win32.Foundation.HANDLE, Descriptor: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR), DescriptorValueDataSize: UInt32, DescriptorValue: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR_VALUE), DescriptorValueSizeRequired: POINTER(UInt16), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTBeginReliableWrite(hDevice: win32more.Windows.Win32.Foundation.HANDLE, ReliableWriteContext: POINTER(UInt64), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTSetCharacteristicValue(hDevice: win32more.Windows.Win32.Foundation.HANDLE, Characteristic: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_CHARACTERISTIC), CharacteristicValue: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_CHARACTERISTIC_VALUE), ReliableWriteContext: UInt64, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTEndReliableWrite(hDevice: win32more.Windows.Win32.Foundation.HANDLE, ReliableWriteContext: UInt64, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTAbortReliableWrite(hDevice: win32more.Windows.Win32.Foundation.HANDLE, ReliableWriteContext: UInt64, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTSetDescriptorValue(hDevice: win32more.Windows.Win32.Foundation.HANDLE, Descriptor: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR), DescriptorValue: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR_VALUE), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTRegisterEvent(hService: win32more.Windows.Win32.Foundation.HANDLE, EventType: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_EVENT_TYPE, EventParameterIn: VoidPtr, Callback: win32more.Windows.Win32.Devices.Bluetooth.PFNBLUETOOTH_GATT_EVENT_CALLBACK, CallbackContext: VoidPtr, pEventHandle: POINTER(IntPtr), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('BluetoothApis.dll')
def BluetoothGATTUnregisterEvent(EventHandle: IntPtr, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class BLUETOOTH_ADDRESS(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        ullLong: UInt64
        rgBytes: Byte * 6
class BLUETOOTH_AUTHENTICATE_RESPONSE(Structure):
    bthAddressRemote: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_ADDRESS
    authMethod: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_METHOD
    Anonymous: _Anonymous_e__Union
    negativeResponse: Byte
    class _Anonymous_e__Union(Union):
        pinInfo: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_PIN_INFO
        oobInfo: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_OOB_DATA_INFO
        numericCompInfo: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_NUMERIC_COMPARISON_INFO
        passkeyInfo: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_PASSKEY_INFO
class BLUETOOTH_AUTHENTICATION_CALLBACK_PARAMS(Structure):
    deviceInfo: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO
    authenticationMethod: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_METHOD
    ioCapability: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_IO_CAPABILITY
    authenticationRequirements: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_REQUIREMENTS
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Numeric_Value: UInt32
        Passkey: UInt32
BLUETOOTH_AUTHENTICATION_METHOD = Int32
BLUETOOTH_AUTHENTICATION_METHOD_LEGACY: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_METHOD = 1
BLUETOOTH_AUTHENTICATION_METHOD_OOB: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_METHOD = 2
BLUETOOTH_AUTHENTICATION_METHOD_NUMERIC_COMPARISON: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_METHOD = 3
BLUETOOTH_AUTHENTICATION_METHOD_PASSKEY_NOTIFICATION: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_METHOD = 4
BLUETOOTH_AUTHENTICATION_METHOD_PASSKEY: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_METHOD = 5
BLUETOOTH_AUTHENTICATION_REQUIREMENTS = Int32
BLUETOOTH_MITM_ProtectionNotRequired: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_REQUIREMENTS = 0
BLUETOOTH_MITM_ProtectionRequired: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_REQUIREMENTS = 1
BLUETOOTH_MITM_ProtectionNotRequiredBonding: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_REQUIREMENTS = 2
BLUETOOTH_MITM_ProtectionRequiredBonding: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_REQUIREMENTS = 3
BLUETOOTH_MITM_ProtectionNotRequiredGeneralBonding: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_REQUIREMENTS = 4
BLUETOOTH_MITM_ProtectionRequiredGeneralBonding: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_REQUIREMENTS = 5
BLUETOOTH_MITM_ProtectionNotDefined: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_REQUIREMENTS = 255
class BLUETOOTH_COD_PAIRS(Structure):
    ulCODMask: UInt32
    pcszDescription: win32more.Windows.Win32.Foundation.PWSTR
class BLUETOOTH_DEVICE_INFO(Structure):
    dwSize: UInt32
    Address: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_ADDRESS
    ulClassofDevice: UInt32
    fConnected: win32more.Windows.Win32.Foundation.BOOL
    fRemembered: win32more.Windows.Win32.Foundation.BOOL
    fAuthenticated: win32more.Windows.Win32.Foundation.BOOL
    stLastSeen: win32more.Windows.Win32.Foundation.SYSTEMTIME
    stLastUsed: win32more.Windows.Win32.Foundation.SYSTEMTIME
    szName: Char * 248
class BLUETOOTH_DEVICE_SEARCH_PARAMS(Structure):
    dwSize: UInt32
    fReturnAuthenticated: win32more.Windows.Win32.Foundation.BOOL
    fReturnRemembered: win32more.Windows.Win32.Foundation.BOOL
    fReturnUnknown: win32more.Windows.Win32.Foundation.BOOL
    fReturnConnected: win32more.Windows.Win32.Foundation.BOOL
    fIssueInquiry: win32more.Windows.Win32.Foundation.BOOL
    cTimeoutMultiplier: Byte
    hRadio: win32more.Windows.Win32.Foundation.HANDLE
class BLUETOOTH_FIND_RADIO_PARAMS(Structure):
    dwSize: UInt32
class BLUETOOTH_GATT_VALUE_CHANGED_EVENT(Structure):
    ChangedAttributeHandle: UInt16
    CharacteristicValueDataSize: UIntPtr
    CharacteristicValue: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_CHARACTERISTIC_VALUE)
class BLUETOOTH_GATT_VALUE_CHANGED_EVENT_REGISTRATION(Structure):
    NumCharacteristics: UInt16
    Characteristics: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_CHARACTERISTIC * 1
BLUETOOTH_IO_CAPABILITY = Int32
BLUETOOTH_IO_CAPABILITY_DISPLAYONLY: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_IO_CAPABILITY = 0
BLUETOOTH_IO_CAPABILITY_DISPLAYYESNO: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_IO_CAPABILITY = 1
BLUETOOTH_IO_CAPABILITY_KEYBOARDONLY: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_IO_CAPABILITY = 2
BLUETOOTH_IO_CAPABILITY_NOINPUTNOOUTPUT: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_IO_CAPABILITY = 3
BLUETOOTH_IO_CAPABILITY_UNDEFINED: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_IO_CAPABILITY = 255
class BLUETOOTH_LOCAL_SERVICE_INFO(Structure):
    Enabled: win32more.Windows.Win32.Foundation.BOOL
    btAddr: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_ADDRESS
    szName: Char * 256
    szDeviceString: Char * 256
class BLUETOOTH_NUMERIC_COMPARISON_INFO(Structure):
    NumericValue: UInt32
class BLUETOOTH_OOB_DATA_INFO(Structure):
    C: Byte * 16
    R: Byte * 16
class BLUETOOTH_PASSKEY_INFO(Structure):
    passkey: UInt32
class BLUETOOTH_PIN_INFO(Structure):
    pin: Byte * 16
    pinLength: Byte
class BLUETOOTH_RADIO_INFO(Structure):
    dwSize: UInt32
    address: win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_ADDRESS
    szName: Char * 248
    ulClassofDevice: UInt32
    lmpSubversion: UInt16
    manufacturer: UInt16
class BLUETOOTH_SELECT_DEVICE_PARAMS(Structure):
    dwSize: UInt32
    cNumOfClasses: UInt32
    prgClassOfDevices: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_COD_PAIRS)
    pszInfo: win32more.Windows.Win32.Foundation.PWSTR
    hwndParent: win32more.Windows.Win32.Foundation.HWND
    fForceAuthentication: win32more.Windows.Win32.Foundation.BOOL
    fShowAuthenticated: win32more.Windows.Win32.Foundation.BOOL
    fShowRemembered: win32more.Windows.Win32.Foundation.BOOL
    fShowUnknown: win32more.Windows.Win32.Foundation.BOOL
    fAddNewDeviceWizard: win32more.Windows.Win32.Foundation.BOOL
    fSkipServicesPage: win32more.Windows.Win32.Foundation.BOOL
    pfnDeviceCallback: win32more.Windows.Win32.Devices.Bluetooth.PFN_DEVICE_CALLBACK
    pvParam: VoidPtr
    cNumDevices: UInt32
    pDevices: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO)
class BTH_DEVICE_INFO(Structure):
    flags: UInt32
    address: UInt64
    classOfDevice: UInt32
    name: win32more.Windows.Win32.Foundation.CHAR * 248
class BTH_HCI_EVENT_INFO(Structure):
    bthAddress: UInt64
    connectionType: Byte
    connected: Byte
class BTH_INFO_REQ(Structure):
    btAddr: UInt64
    infoType: UInt16
    _pack_ = 1
class BTH_INFO_RSP(Structure):
    result: UInt16
    dataLen: Byte
    Anonymous: _Anonymous_e__Union
    _pack_ = 1
    class _Anonymous_e__Union(Union):
        connectionlessMTU: UInt16
        data: Byte * 44
        _pack_ = 1
class BTH_L2CAP_EVENT_INFO(Structure):
    bthAddress: UInt64
    psm: UInt16
    connected: Byte
    initiated: Byte
class BTH_LE_GATT_CHARACTERISTIC(Structure):
    ServiceHandle: UInt16
    CharacteristicUuid: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_UUID
    AttributeHandle: UInt16
    CharacteristicValueHandle: UInt16
    IsBroadcastable: win32more.Windows.Win32.Foundation.BOOLEAN
    IsReadable: win32more.Windows.Win32.Foundation.BOOLEAN
    IsWritable: win32more.Windows.Win32.Foundation.BOOLEAN
    IsWritableWithoutResponse: win32more.Windows.Win32.Foundation.BOOLEAN
    IsSignedWritable: win32more.Windows.Win32.Foundation.BOOLEAN
    IsNotifiable: win32more.Windows.Win32.Foundation.BOOLEAN
    IsIndicatable: win32more.Windows.Win32.Foundation.BOOLEAN
    HasExtendedProperties: win32more.Windows.Win32.Foundation.BOOLEAN
class BTH_LE_GATT_CHARACTERISTIC_VALUE(Structure):
    DataSize: UInt32
    Data: Byte * 1
class BTH_LE_GATT_DESCRIPTOR(Structure):
    ServiceHandle: UInt16
    CharacteristicHandle: UInt16
    DescriptorType: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR_TYPE
    DescriptorUuid: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_UUID
    AttributeHandle: UInt16
BTH_LE_GATT_DESCRIPTOR_TYPE = Int32
CharacteristicExtendedProperties: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR_TYPE = 0
CharacteristicUserDescription: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR_TYPE = 1
ClientCharacteristicConfiguration: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR_TYPE = 2
ServerCharacteristicConfiguration: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR_TYPE = 3
CharacteristicFormat: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR_TYPE = 4
CharacteristicAggregateFormat: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR_TYPE = 5
CustomDescriptor: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR_TYPE = 6
class BTH_LE_GATT_DESCRIPTOR_VALUE(Structure):
    DescriptorType: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_DESCRIPTOR_TYPE
    DescriptorUuid: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_UUID
    Anonymous: _Anonymous_e__Union
    DataSize: UInt32
    Data: Byte * 1
    class _Anonymous_e__Union(Union):
        CharacteristicExtendedProperties: _CharacteristicExtendedProperties_e__Struct
        ClientCharacteristicConfiguration: _ClientCharacteristicConfiguration_e__Struct
        ServerCharacteristicConfiguration: _ServerCharacteristicConfiguration_e__Struct
        CharacteristicFormat: _CharacteristicFormat_e__Struct
        class _CharacteristicExtendedProperties_e__Struct(Structure):
            IsReliableWriteEnabled: win32more.Windows.Win32.Foundation.BOOLEAN
            IsAuxiliariesWritable: win32more.Windows.Win32.Foundation.BOOLEAN
        class _ClientCharacteristicConfiguration_e__Struct(Structure):
            IsSubscribeToNotification: win32more.Windows.Win32.Foundation.BOOLEAN
            IsSubscribeToIndication: win32more.Windows.Win32.Foundation.BOOLEAN
        class _ServerCharacteristicConfiguration_e__Struct(Structure):
            IsBroadcast: win32more.Windows.Win32.Foundation.BOOLEAN
        class _CharacteristicFormat_e__Struct(Structure):
            Format: Byte
            Exponent: Byte
            Unit: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_UUID
            NameSpace: Byte
            Description: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_UUID
BTH_LE_GATT_EVENT_TYPE = Int32
CharacteristicValueChangedEvent: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_EVENT_TYPE = 0
class BTH_LE_GATT_SERVICE(Structure):
    ServiceUuid: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_UUID
    AttributeHandle: UInt16
class BTH_LE_UUID(Structure):
    IsShortUuid: win32more.Windows.Win32.Foundation.BOOLEAN
    Value: _Value_e__Union
    class _Value_e__Union(Union):
        ShortUuid: UInt16
        LongUuid: Guid
class BTH_PING_REQ(Structure):
    btAddr: UInt64
    dataLen: Byte
    data: Byte * 44
    _pack_ = 1
class BTH_PING_RSP(Structure):
    dataLen: Byte
    data: Byte * 44
class BTH_QUERY_DEVICE(Structure):
    LAP: UInt32
    length: Byte
    _pack_ = 1
class BTH_QUERY_SERVICE(Structure):
    type: UInt32
    serviceHandle: UInt32
    uuids: win32more.Windows.Win32.Devices.Bluetooth.SdpQueryUuid * 12
    numRange: UInt32
    pRange: win32more.Windows.Win32.Devices.Bluetooth.SdpAttributeRange * 1
    _pack_ = 1
class BTH_RADIO_IN_RANGE(Structure):
    deviceInfo: win32more.Windows.Win32.Devices.Bluetooth.BTH_DEVICE_INFO
    previousDeviceFlags: UInt32
class BTH_SET_SERVICE(Structure):
    pSdpVersion: POINTER(UInt32)
    pRecordHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)
    fCodService: UInt32
    Reserved: UInt32 * 5
    ulRecordLength: UInt32
    pRecord: Byte * 1
    _pack_ = 1
HANDLE_SDP_TYPE = UInt64
HBLUETOOTH_DEVICE_FIND = VoidPtr
HBLUETOOTH_RADIO_FIND = VoidPtr
IO_CAPABILITY = Int32
IoCaps_DisplayOnly: win32more.Windows.Win32.Devices.Bluetooth.IO_CAPABILITY = 0
IoCaps_DisplayYesNo: win32more.Windows.Win32.Devices.Bluetooth.IO_CAPABILITY = 1
IoCaps_KeyboardOnly: win32more.Windows.Win32.Devices.Bluetooth.IO_CAPABILITY = 2
IoCaps_NoInputNoOutput: win32more.Windows.Win32.Devices.Bluetooth.IO_CAPABILITY = 3
IoCaps_Undefined: win32more.Windows.Win32.Devices.Bluetooth.IO_CAPABILITY = 255
NodeContainerType = Int32
NodeContainerTypeSequence: win32more.Windows.Win32.Devices.Bluetooth.NodeContainerType = 0
NodeContainerTypeAlternative: win32more.Windows.Win32.Devices.Bluetooth.NodeContainerType = 1
@winfunctype_pointer
def PFNBLUETOOTH_GATT_EVENT_CALLBACK(EventType: win32more.Windows.Win32.Devices.Bluetooth.BTH_LE_GATT_EVENT_TYPE, EventOutParameter: VoidPtr, Context: VoidPtr) -> Void: ...
@winfunctype_pointer
def PFN_AUTHENTICATION_CALLBACK(pvParam: VoidPtr, pDevice: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_AUTHENTICATION_CALLBACK_EX(pvParam: VoidPtr, pAuthCallbackParams: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_AUTHENTICATION_CALLBACK_PARAMS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_BLUETOOTH_ENUM_ATTRIBUTES_CALLBACK(uAttribId: UInt32, pValueStream: POINTER(Byte), cbStreamSize: UInt32, pvParam: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFN_DEVICE_CALLBACK(pvParam: VoidPtr, pDevice: POINTER(win32more.Windows.Win32.Devices.Bluetooth.BLUETOOTH_DEVICE_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
class RFCOMM_COMMAND(Structure):
    CmdType: UInt32
    Data: _Data_e__Union
    _pack_ = 1
    class _Data_e__Union(Union):
        MSC: win32more.Windows.Win32.Devices.Bluetooth.RFCOMM_MSC_DATA
        RLS: win32more.Windows.Win32.Devices.Bluetooth.RFCOMM_RLS_DATA
        RPN: win32more.Windows.Win32.Devices.Bluetooth.RFCOMM_RPN_DATA
class RFCOMM_MSC_DATA(Structure):
    Signals: Byte
    Break: Byte
class RFCOMM_RLS_DATA(Structure):
    LineStatus: Byte
class RFCOMM_RPN_DATA(Structure):
    Baud: Byte
    Data: Byte
    FlowControl: Byte
    XonChar: Byte
    XoffChar: Byte
    ParameterMask1: Byte
    ParameterMask2: Byte
class SDP_ELEMENT_DATA(Structure):
    type: win32more.Windows.Win32.Devices.Bluetooth.SDP_TYPE
    specificType: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE
    data: _data_e__Union
    class _data_e__Union(Union):
        int128: win32more.Windows.Win32.Devices.Bluetooth.SDP_LARGE_INTEGER_16
        int64: Int64
        int32: Int32
        int16: Int16
        int8: win32more.Windows.Win32.Foundation.CHAR
        uint128: win32more.Windows.Win32.Devices.Bluetooth.SDP_ULARGE_INTEGER_16
        uint64: UInt64
        uint32: UInt32
        uint16: UInt16
        uint8: Byte
        booleanVal: Byte
        uuid128: Guid
        uuid32: UInt32
        uuid16: UInt16
        string: _string_e__Struct
        url: _url_e__Struct
        sequence: _sequence_e__Struct
        alternative: _alternative_e__Struct
        class _string_e__Struct(Structure):
            value: POINTER(Byte)
            length: UInt32
        class _url_e__Struct(Structure):
            value: POINTER(Byte)
            length: UInt32
        class _sequence_e__Struct(Structure):
            value: POINTER(Byte)
            length: UInt32
        class _alternative_e__Struct(Structure):
            value: POINTER(Byte)
            length: UInt32
class SDP_LARGE_INTEGER_16(Structure):
    LowPart: UInt64
    HighPart: Int64
SDP_SPECIFICTYPE = Int32
SDP_ST_NONE: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 0
SDP_ST_UINT8: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 16
SDP_ST_UINT16: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 272
SDP_ST_UINT32: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 528
SDP_ST_UINT64: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 784
SDP_ST_UINT128: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 1040
SDP_ST_INT8: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 32
SDP_ST_INT16: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 288
SDP_ST_INT32: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 544
SDP_ST_INT64: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 800
SDP_ST_INT128: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 1056
SDP_ST_UUID16: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 304
SDP_ST_UUID32: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 544
SDP_ST_UUID128: win32more.Windows.Win32.Devices.Bluetooth.SDP_SPECIFICTYPE = 1072
class SDP_STRING_TYPE_DATA(Structure):
    encoding: UInt16
    mibeNum: UInt16
    attributeId: UInt16
SDP_TYPE = Int32
SDP_TYPE_NIL: win32more.Windows.Win32.Devices.Bluetooth.SDP_TYPE = 0
SDP_TYPE_UINT: win32more.Windows.Win32.Devices.Bluetooth.SDP_TYPE = 1
SDP_TYPE_INT: win32more.Windows.Win32.Devices.Bluetooth.SDP_TYPE = 2
SDP_TYPE_UUID: win32more.Windows.Win32.Devices.Bluetooth.SDP_TYPE = 3
SDP_TYPE_STRING: win32more.Windows.Win32.Devices.Bluetooth.SDP_TYPE = 4
SDP_TYPE_BOOLEAN: win32more.Windows.Win32.Devices.Bluetooth.SDP_TYPE = 5
SDP_TYPE_SEQUENCE: win32more.Windows.Win32.Devices.Bluetooth.SDP_TYPE = 6
SDP_TYPE_ALTERNATIVE: win32more.Windows.Win32.Devices.Bluetooth.SDP_TYPE = 7
SDP_TYPE_URL: win32more.Windows.Win32.Devices.Bluetooth.SDP_TYPE = 8
SDP_TYPE_CONTAINER: win32more.Windows.Win32.Devices.Bluetooth.SDP_TYPE = 32
class SDP_ULARGE_INTEGER_16(Structure):
    LowPart: UInt64
    HighPart: UInt64
class SOCKADDR_BTH(Structure):
    addressFamily: UInt16
    btAddr: UInt64
    serviceClassId: Guid
    port: UInt32
    _pack_ = 1
class SdpAttributeRange(Structure):
    minAttribute: UInt16
    maxAttribute: UInt16
class SdpQueryUuid(Structure):
    u: win32more.Windows.Win32.Devices.Bluetooth.SdpQueryUuidUnion
    uuidType: UInt16
class SdpQueryUuidUnion(Union):
    uuid128: Guid
    uuid32: UInt32
    uuid16: UInt16


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.UI.WindowManagement
import win32more.Windows.UI.WindowManagement.Preview
import win32more.Windows.Win32.System.WinRT
class IWindowManagementPreview(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.WindowManagement.Preview.IWindowManagementPreview'
    _iid_ = Guid('{4ef55b0d-561d-513c-a67c-2c02b69cef41}')
class IWindowManagementPreviewStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.WindowManagement.Preview.IWindowManagementPreviewStatics'
    _iid_ = Guid('{0f9725c6-c004-5a23-8fd2-8d092ce2704a}')
    @winrt_commethod(6)
    def SetPreferredMinSize(self, window: win32more.Windows.UI.WindowManagement.AppWindow, preferredFrameMinSize: win32more.Windows.Foundation.Size) -> Void: ...
class WindowManagementPreview(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.WindowManagement.Preview.IWindowManagementPreview
    _classid_ = 'Windows.UI.WindowManagement.Preview.WindowManagementPreview'
    @winrt_classmethod
    def SetPreferredMinSize(cls: win32more.Windows.UI.WindowManagement.Preview.IWindowManagementPreviewStatics, window: win32more.Windows.UI.WindowManagement.AppWindow, preferredFrameMinSize: win32more.Windows.Foundation.Size) -> Void: ...


make_ready(__name__)
